Package: FAwR
Type: Package
Title: Functions and Datasets for "Forest Analytics with R"
Version: 1.2.0
Date: 2025-06-22
Maintainer: Andrew Robinson <apro@unimelb.edu.au>
Depends: R (>= 2.10), MASS, lattice
Description: Provides functions and datasets from the book "Forest Analytics with R".
License: GPL-3
LazyLoad: yes
Authors@R: c(person(given = "Andrew",
                    family = "Robinson",
                    role = c("aut", "cre"),
                    email = "apro@unimelb.edu.au"),
             person(given = "Jeff",
                    family = "Hamann",
                    role = "aut"))
NeedsCompilation: no
Packaged: 2025-06-22 07:21:20 UTC; root
Author: Andrew Robinson [aut, cre],
  Jeff Hamann [aut]
Repository: CRAN
Date/Publication: 2025-06-22 09:40:05 UTC
Built: R 4.6.0; ; 2026-04-26 17:56:58 UTC; unix
